# Vega API client

![Python tests](https://github.com/vegaprotocol/api/workflows/Python%20tests/badge.svg?branch=master)

This is the Vega API client, which talks to a Vega node using gRPC, and to a Vega Wallet server using REST.

## Disclaimer

This is a community effort. It is not supported by Vega, nor is it guaranteed
to be up to date or compatible with new Vega releases.

## Examples

For examples, see the [sample API scripts](https://github.com/vegaprotocol/sample-api-scripts/) repository.
